API Reference
==============

Here is the reference documentation for the eprllib API. This library provides a set of tools and utilities 
for the simulation and evaluation of multi-agent environments in EnergyPlus.

.. automodule:: eprllib

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   Env
       This module contains configurations and utilities for creating and managing simulation environments in EnergyPlus.
   Agents
       This module defines the specifications and behaviors of the agents interacting in the simulated environments.
   AgentsConnectors
       This module provides connectors for integrating agents with different environments and platforms.
   Episodes
       This module handles functions and utilities related to the management of simulation episodes.
   Utils
       This module includes various utilities and auxiliary functions that facilitate the configuration and execution of simulations.
   PostProcess
       This module offers tools for analyzing and processing the results obtained from the simulations.
